@@ -10,14 +10,28 @@ use super::goal::*;
 pub struct State {
 	
 	pub(crate) history: Vec<Rc<Event>>,
-	pub(crate) current_page: Rc<Page>,
+	pub(crate) page: Rc<Page>,
 	pub(crate) index: usize,
 	
 }
 
 impl<'state> State {
 
-	/// Creates a [`Page`] from `path`, assigning it to `self.current_page`.
+	/// `self.index`
+	pub fn index(&self) -> usize {
+
+		self.index
+
+	}
+
+	/// `self.page`
+	pub fn page(&self) -> Rc<Page> {
+
+		Rc::clone(&self.page)
+
+	}
+
+	/// Creates a [`Page`] from `path`, assigning it to `self.page`.
 	pub fn read_file(&mut self, path: &Path) -> Result<()> {
 
 		let string_maybe = read_to_string(path);
@@ -36,7 +50,7 @@ impl<'state> State {
 				let page = Page::from(string.as_str());
 				let shared_page = Rc::new(page);
 
-				self.current_page = shared_page;
+				self.page = shared_page;
 				
 				let description = format!("Opened '{path_display}'.");
 				let status = Status::Success(description);
@@ -84,7 +98,7 @@ impl<'state> State {
 	/// Starts an [`Event`].
 	pub(crate) fn start_event(&self, goal: Goal) -> Start  {
 		
-		let ref page = Rc::clone(&self.current_page);
+		let ref page = Rc::clone(&self.page);
 		
 		let place = Place::new(page, self.index);
 		let time = SystemTime::now();
@@ -96,7 +110,7 @@ impl<'state> State {
 	/// Advances `self.index` by the amount given.
 	pub fn advance(&mut self, amount: usize) -> Result<()> {
 
-		let string = self.current_page.string.as_ref();
+		let string = self.page.string.as_ref();
 		let string_length = string.len();
 
 		for n in 0..amount {
@@ -124,11 +138,11 @@ impl<'state> State {
 	pub(crate) fn end_event(&mut self, start: Start, status: Status) -> Receipt {
 		
 		let time = SystemTime::now();
-		let place = Place::new(&self.current_page, self.index);
+		let place = Place::new(&self.page, self.index);
 
 		let end = End { time, place, status };
 		
-		let page = Rc::clone(&self.current_page);
+		let page = Rc::clone(&self.page);
 
 		let event = Event { start, end, page };
 
@@ -166,13 +180,13 @@ impl From<Page> for State {
 
 	fn from(page: Page) -> Self {
 
-		let current_page = Rc::new(page);
+		let page = Rc::new(page);
 
 		let index = 0;
 
 		let history = Default::default();
 
-		Self { current_page, index, history }
+		Self { page, index, history }
 
 	}
 
